@@ -9,7 +9,7 @@ from django.contrib.staticfiles.testing import LiveServerTestCase
 
 
 @pytest.mark.client
-@pytest.mark.usefixtures("import_translations_fixture")
+@pytest.mark.usefixtures("import_german_translations_fixture")
 class TestTranslateClientModel(LiveServerTestCase):
     """Tests for ``TranslateClient`` utils methods."""
 
@@ -286,3 +286,54 @@ class TestTranslateClientModel(LiveServerTestCase):
         )
         assert keys.pop("filter_start_date_on_website") == "Startdatum auf Webseite"
         assert len(keys) == 0
+
+    def test_snake_key(self):
+        """Test id_name method for fetching individual keys"""
+        from melon_translate_client import Client
+
+        port = self.live_server_url.split(":")[2]
+        client = Client(config("TRANSLATE_ADDRESS", default="http://localhost"), port)
+        language = "de"
+        view = "translation_center"
+
+        _ = client.filter(language, views=[view])
+        test_snake_key = "general_conditions"
+
+        id_name_key_obj = client.snake_key(language, test_snake_key)
+
+        assert id_name_key_obj
+        assert id_name_key_obj.get("translation"), "Should not be empty"
+        assert (
+            id_name_key_obj.get("key").get("snake_name") == "general_conditions"
+        ), "Assert prober key is returned"
+        assert (
+            id_name_key_obj.get("language").get("lang_info").get("code") == "de"
+        ), "Should be german language"
+
+    def test_id_name(self):
+        """Test id_name method for fetching individual keys"""
+        from melon_translate_client import Client
+
+        port = self.live_server_url.split(":")[2]
+        client = Client(config("TRANSLATE_ADDRESS", default="http://localhost"), port)
+        language = "de"
+        occurrences = "new_mdt/apps/mdt_apartments/api/docs.py"
+
+        _ = client.filter(language, occurrences=[occurrences])
+        test_snake_key = "VM anfragen"
+        test_snake_key_2 = "Bedingungen"
+
+        id_name_key_obj = client.id_name(language, test_snake_key)
+        id_name_key_obj_2 = client.id_name(language, test_snake_key_2)
+
+        assert id_name_key_obj
+        assert id_name_key_obj.get("translation"), "Should not be empty"
+        assert (
+            id_name_key_obj.get("language").get("lang_info").get("code") == "de"
+        ), "Should be german language"
+
+        assert id_name_key_obj_2
+        assert id_name_key_obj_2.get("translation"), "Should not be empty"
+        assert (
+            id_name_key_obj_2.get("language").get("lang_info").get("code") == "de"
+        ), "Should be german language"
